@@ -38,7 +38,7 @@ class Email(Field):
             [a-zA-Z0-9._%+-]+           # email-username
             @
             [a-zA-Z0-9.-]+              # domain-name
-            \.[a-zA-Z]{2,4}             # dot-something
+            \.[a-zA-Z]+             # dot-something
             )''', re.VERBOSE)
 
         s = re.search(p, value)
